@@ -24,7 +24,7 @@ class Renderer(base.Renderer, browser.SlideShowPortletView):
     @property.Lazy
     def image_data(self):
         return '{ ' + ','.join([
-            "'%s': { capton: '%s' }" % (
+            "'%s': { caption: '%s' }" % (
                 image['name'], image['caption']) for image in
             self.getSlideshowImages()]) + ' }'
 
