@@ -18,7 +18,8 @@ class InstallLayer(tcl_ptc.BasePTCLayer):
         self.portal.images.invokeFactory(
             type_name='Image', id='foo-image-title',
             title='Foo Image Title',
-            description='Foo Image description',
+            description=u'Foo Image description',
+            creators=[u'Foo Cre\xc3tor'],
             image=self.portal['document_icon.gif']._readFile(False))
 
         self.login()
@@ -30,7 +31,7 @@ class InstallLayer(tcl_ptc.BasePTCLayer):
         self.folder.slideshow.invokeFactory(
             type_name='Image', id='bar-image-title',
             title='Bar Image Title',
-            description='Bar Image description')
+            description=u'Bar Im\xc3ge description')
         
 install_layer = InstallLayer([tcl_ptc.ptc_layer])
     
