@@ -11,7 +11,7 @@ from collective.slideshowfolder import testing
 
 def test_suite():
     install_suite = ZopeTestCase.FunctionalDocFileSuite(
-        'README.txt',
+        'README.txt', 'portlets.txt',
         optionflags=optionflags,
         test_class=ptc.FunctionalTestCase)
     install_suite.layer = testing.install_layer
